// Copyright (c) Microsoft Corporation.  All rights reserved.

//------------------------------------------------------------------------------
// PLEASE NOTE:  Microsoft Corporation (or based on where you live, one of its affiliates) 
// licenses this supplement to you.  You may use it with each validly licensed copy of Microsoft 
// Visual Studio Pre-Release Code-Name "ORCAS" software (the “software”).  You may not use the 
// supplement if you do not have a license for the software.  The license terms for the software 
// apply to your use of this supplement. 
//
// Please note: As this software is distributed in Quebec, Canada, this notice is provided below in French.
// Remarque: Ce logiciel étant distribué au Québec, Canada, les termes de cette licence sont fournis ci-dessous en français.
// REMARQUE:  Microsoft Corporation (ou en fonction du lieu où vous vivez, l’un de ses affiliés) vous 
// accorde une licence pour ce supplément.  Vous pouvez utiliser une copie de ce supplément avec chaque 
// copie concédée sous licence du logiciel Microsoft Visual Studio Pre-Release Code-Name "ORCAS" (le « logiciel »).  
// Vous n’êtes pas autorisé à utiliser ce supplément si vous n’êtes pas titulaire d’une licence pour le logiciel.  
// Les conditions de licence pour le logiciel s’appliquent à l’utilisation de ce supplément.  
//------------------------------------------------------------------------------
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Data.Objects;


using NorthwindLib;

public partial class ProductDetails : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e) {
        if(!IsPostBack) {

            using(Northwind db = new Northwind((string)Application["ConnectionString"])) {
              

                //// load the categories into the categories combobox
                ObjectQuery<Category> categories = db.CreateQuery<Category>("Select value c from Categories as c order by c.CategoryName");
                foreach (Category c in categories)
                {
                    cmbCategories.Items.Add(new ListItem(c.CategoryName, c.CategoryID.ToString()));
                }

                // if a product ID is passed in the query string, then
                // load that product, otherwise start with the fields
                // blank
                int productId;
                if(int.TryParse(Request["productId"], out productId)) {

                    Product product = ProductHelper.FindProductByID(productId, db); //Products.FindProductByID(productId,db);

                    lblProductID.Text = product.ProductID.ToString();
                    txtProductName.Text = product.ProductName;
                    txtUnitPrice.Text = product.UnitPrice.ToString();

                    // find the category and mark it as selected in the combobox
                    product.CategoryReference.Load();
                    ListItem item = cmbCategories.Items.FindByValue(product.Category.CategoryID.ToString());
                    if (null != item) item.Selected = true;
                }
            }
        }
    }

    protected void btnNewProduct_Click(object sender, EventArgs e) {
        // Redirect instead of clearing out the fields so we
        // get a URL that doesn't contain the current product ID
        Response.Redirect("ProductDetails.aspx");
    }

    protected void btnUpdate_Click(object sender, EventArgs e) {
        

        // look-up the product in the database, update it to the
        // new values and push the change back into the store. If this
        // is a new product we can skip the look up part.
        using(Northwind db = new Northwind((string)Application["ConnectionString"])) {

            Product product;
            if(lblProductID.Text != string.Empty) {
                int productId = int.Parse(lblProductID.Text);
                product = ProductHelper.FindProductByID(productId,db);
                // load the category for this product as well
                product.CategoryReference.Load();
            }
            else {
                product = new Product();
            }

            product.ProductName = txtProductName.Text;
            product.UnitPrice = decimal.Parse(txtUnitPrice.Text); // let it fail if format is incorrect
            
            // find the category picked by the user
            int categoryId = int.Parse(cmbCategories.SelectedValue);
            Category category = CategoryHelper.FindCategoryByID(categoryId, db);
            product.Category = category;
            db.SaveChanges();

            // at this point the system updated the product id in the product object,
            // so we can update the label to show the new id
            lblProductID.Text = product.ProductID.ToString();
        }
    }


    protected void lnkShowCategory_Click(object sender, EventArgs e) {
        // find the category picked by the user
        int categoryId = int.Parse(cmbCategories.SelectedValue);

        // redirect to the product listing page
        Response.Redirect("Products.aspx?categoryId=" + categoryId);
    }
}
