' Copyright (c) Microsoft Corporation.  All rights reserved.

'------------------------------------------------------------------------------
' PLEASE NOTE:  Microsoft Corporation (or based on where you live, one of its affiliates) 
' licenses this supplement to you.  You may use it with each validly licensed copy of Microsoft 
' Visual Studio Pre-Release Code-Name "ORCAS" software (the “software”).  You may not use the 
' supplement if you do not have a license for the software.  The license terms for the software 
' apply to your use of this supplement. 
'
' Please note: As this software is distributed in Quebec, Canada, this notice is provided below in French.
' Remarque: Ce logiciel étant distribué au Québec, Canada, les termes de cette licence sont fournis ci-dessous en français.
' REMARQUE:  Microsoft Corporation (ou en fonction du lieu où vous vivez, l’un de ses affiliés) vous 
' accorde une licence pour ce supplément.  Vous pouvez utiliser une copie de ce supplément avec chaque 
' copie concédée sous licence du logiciel Microsoft Visual Studio Pre-Release Code-Name "ORCAS" (le « logiciel »).  
' Vous n’êtes pas autorisé à utiliser ce supplément si vous n’êtes pas titulaire d’une licence pour le logiciel.  
' Les conditions de licence pour le logiciel s’appliquent à l’utilisation de ce supplément.  
'------------------------------------------------------------------------------
Imports NorthwindLib
Imports System.Data.Objects


Public Partial Class ProductDetails
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        If Not IsPostBack Then
            Using db As New Northwind(CType(Application("ConnectionString"), String))

                Dim c As Category

                ' load the categories into the categories combobox
                Dim categories As ObjectQuery(Of Category) = db.CreateQuery(Of Category)("Select value c from Categories as c order by c.CategoryName")

                For Each c In categories
                    cmbCategories.Items.Add(New ListItem(c.CategoryName, c.CategoryID.ToString()))
                Next


                ' ObjectQuery<Product> products = db.CreateQuery<Product>(
                ' "Select value p from Products as p where p.ProductID == @productID", new ObjectParameter("productID", productID));

                ' if a product ID is passed in the query string, then
                ' load that product, otherwise start with the fields
                ' blank
                Dim productId As Integer
                If Integer.TryParse(Request("productId"), productId) Then
                    Dim p As Product = db.CreateQuery(Of Product)("Select value p from Products as p where p.ProductID == @productID", New ObjectParameter("productID", productId)).First()

                    lblProductID.Text = p.ProductID.ToString()
                    txtProductName.Text = p.ProductName
                    txtUnitPrice.Text = p.UnitPrice.ToString()

                    ' find the category and mark it as selected in the combobox
                    p.CategoryReference.Load()
                    Dim item As ListItem = cmbCategories.Items.FindByValue(p.Category.CategoryID.ToString())
                    If item IsNot Nothing Then item.Selected = True
                End If
            End Using
        End If
    End Sub

    Protected Sub btnNewProduct_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnNewProduct.Click
        ' Redirect instead of clearing out the fields so we
        ' get a URL that doesn't contain the current product ID
        Response.Redirect("ProductDetails.aspx")
    End Sub

    Protected Sub btnUpdate_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnUpdate.Click
        ' look-up the product in the database, update it to the
        ' new values and push the change back into the store. If this
        ' is a new product we can skip the look up part.
        Using db As New Northwind(CType(Application("ConnectionString"), String))

            Dim p As Product
            If lblProductID.Text <> String.Empty Then
                Dim productId As Integer = Integer.Parse(lblProductID.Text)
                p = db.CreateQuery(Of Product)("Select value p from Products as p where p.ProductID == @productID", New ObjectParameter("productID", productId)).First()

                ' load the category for this product
                p.CategoryReference.Load()
            Else
                p = New Product()
            End If

            p.ProductName = txtProductName.Text
            p.UnitPrice = Decimal.Parse(txtUnitPrice.Text) ' let it fail if format is incorrect

            ' find the category picked by the user
            Dim categoryId As Integer = Integer.Parse(cmbCategories.SelectedValue)
            Dim cat As Category = db.CreateQuery(Of Category)("Select value c from Categories as c where c.CategoryID == @categoryID", New ObjectParameter("categoryID", categoryId)).First()

            p.Category = cat

            db.SaveChanges()

            ' at this point the system updated the product id in the product object,
            ' so we can update the label to show the new id
            lblProductID.Text = p.ProductID.ToString()
        End Using
    End Sub



    Protected Sub lnkShowCategory_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lnkShowCategory.Click
        ' find the category picked by the user
        Dim categoryId As Integer = Integer.Parse(cmbCategories.SelectedValue)

        ' redirect to the product listing page
        Response.Redirect("Products.aspx?categoryId=" & categoryId)
    End Sub
End Class
